//package de.intevation.mxd.reader;

import java.io.IOException;

import org.apache.log4j.Logger;

import com.esri.arcgis.display.ISymbol;
import com.esri.arcgis.display.SimpleMarkerSymbol;
import com.esri.arcgis.display.esriSimpleMarkerStyle;
import com.esri.arcgis.display.IRgbColor;
import com.esri.arcgis.display.RgbColor;

import org.w3c.dom.Element;

/**
 * Reads simple marker symbol information.
 *
 * @author <a href="mailto:raimund.renkert@intevation.de">Raimund Renkert</a>
 */
public class SimpleMarkerSymbolReader implements ISymbolReader{

    /**
     * The logger.
     */
    private static final Logger logger =
        Logger.getLogger(SimpleMarkerSymbolReader.class);

    /**
     * Private member.
     */
    private Element renderer;
    private SimpleMarkerSymbol symbol;
    private MapToXMLUtils util;


    public SimpleMarkerSymbolReader(ISymbol symbol) throws Exception{
        logger.debug("contructor()");
        if(symbol instanceof SimpleMarkerSymbol)
            this.symbol = (SimpleMarkerSymbol)symbol;
        else
            throw new Exception("Not a SimpleMarkerSymbol!");
    }

    /**
     * Setter for the parent XML element.
     *
     * @param parent The XML parent node.
     */
    public void setParent(Element parent) {
        this.renderer = parent;
    }

    /**
     * Setter for XML document helper.
     *
     * @param util The helper class for storing map information.
     */
    public void setUtil(MapToXMLUtils util) {
        this.util = util;
    }

    /**
     * Reads the symbol attributes.
     *
     * @return The XML node.
     */
    public Element read()
    throws IOException {
        logger.debug("read()");
        Element symbolElement;
        try {
            symbolElement = util.addSymbol(renderer);
        }
        catch(Exception e) {
            e.printStackTrace();
            return null;
        }

        symbolElement.setAttribute("name", symbol.getNameString());
        if(symbol.getStyle() == esriSimpleMarkerStyle.esriSMSCircle)
            symbolElement.setAttribute("style", "point");

        if(symbol.getColor() instanceof IRgbColor) {
            IRgbColor color = (IRgbColor)symbol.getColor();
            symbolElement.setAttribute("color",  "(" + color.getRed() +
                "," + color.getGreen() +
                "," + color.getBlue() + ")");
            symbolElement.setAttribute("transparency",
                String.valueOf(color.getTransparency()));
        }
        else {
            System.out.println("Color type unknown! " +
                symbol.getColor().getClass().toString());
        }

        symbolElement.setAttribute("size", String.valueOf(symbol.getSize()));
        symbolElement.setAttribute("outline_size",
            String.valueOf(symbol.getOutlineSize()));
        if(symbol.getOutlineColor() instanceof IRgbColor) {
            IRgbColor color = (IRgbColor)symbol.getOutlineColor();
            symbolElement.setAttribute("outline_color",  "(" + color.getRed() +
                "," + color.getGreen() +
                "," + color.getBlue() + ")");
            symbolElement.setAttribute("outline_transparency",
                String.valueOf(color.getTransparency()));
        }
        else {
            System.out.println("Color type unknown! " +
                               symbol.getColor().getClass().toString());
        }

        symbolElement.setAttribute("angle", String.valueOf(symbol.getAngle()));
        symbolElement.setAttribute("offset",
            symbol.getXOffset() + "," + symbol.getYOffset());

        return symbolElement;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
